Method: Footnotes::Notes::AbstractNote#legend
- Defined in:
- lib/sinatra-footnotes/notes/abstract_note.rb
#legend ⇒ Object
If has_fieldset? is true, create a fieldset with the value returned as legend. By default, returns the title of the class (defined above).
77 78 79 |
# File 'lib/sinatra-footnotes/notes/abstract_note.rb', line 77 def legend self.class.title end |